@@ -6,7 +6,12 @@ IsRegular = function(t){
   tt = unlist(t);
   f = length(tt)/length(unique(tt))/length(t);
   if (f == 1){
-    return('Dense'); # for either regular and irregular data
+    if(length(unique(tt))<8){ #In case of low number of observations per subject
+      return('Sparse');
+    }
+    else{
+      return('Dense'); # for either regular and irregular data
+    }
   } else if(f > 0.80){
     return('DenseWithMV');
   } else {
